@@ -6,10 +6,10 @@ Start Date        : 19971205
 
 Description        :
 
-$Id: directive.py 893 2007-12-09 07:08:16Z chris $
+$Id: directive.py 923 2009-03-02 07:34:24Z chris $
 '''
 
-__version__ = '$Revision: 893 $'
+__version__ = '$Revision: 923 $'
 
 __copyright__ = 'Copyright (c) Chris Miles 1997-2005'
 
@@ -57,6 +57,10 @@ class DirectiveError(Exception):
     """
 
 
+class TemplateDirective(Exception):
+    """Directive being parsed is a template.
+    """
+
 
 ##
 ## Directive management objects
@@ -555,7 +559,7 @@ class Directive:
 
         if self.args.template == 'self':
             # jump out of token parsing if this is a template only
-            raise 'Template'
+            raise TemplateDirective
 
 
     def evalAction(self, actioncall):
